@@ -7,9 +7,13 @@ def reset_max_id_for_series(schema: str, table: str, col: str, cursor):
     cursor.execute(f"SELECT setval('{table}_{col}_seq', (SELECT MAX({col}) FROM \"{schema}.{table}\"));")
 
 
-Min_DB_Id_Series: Final = 100000
+Min_DB_Id_Series: Final = 1000000
 MIN_TEST_Id_Series: Final = 10000
-MAX_TEST_Id_Series: Final = 20000
+MAX_TEST_Id_Series: Final = 50000
+
+
+def rand_test_id() -> str:
+    return f'{ID_PREFIX}{random.randint(MIN_TEST_Id_Series, MAX_TEST_Id_Series)}'
 
 
 # @ref https://www.postgresql.org/docs/current/functions-sequence.html
